@@ -11,7 +11,7 @@ import operator as op
 import pathlib
 import time
 from functools import reduce
-from typing import Any
+from typing import Any, Callable, Iterable
 
 import cairo
 import numpy as np
@@ -30,6 +30,13 @@ from ..utils.images import get_full_raster_image_path
 from ..utils.iterables import list_difference_update
 from ..utils.space_ops import angle_of_vector
 
+LINE_JOIN_MAP = {
+    LineJointType.AUTO: None,  # TODO: this could be improved
+    LineJointType.ROUND: cairo.LineJoin.ROUND,
+    LineJointType.BEVEL: cairo.LineJoin.BEVEL,
+    LineJointType.MITER: cairo.LineJoin.MITER,
+}
+
 
 class Camera:
     """Base camera class.
@@ -37,50 +44,44 @@ class Camera:
     This is the object which takes care of what exactly is displayed
     on screen at any given moment.
 
-    Some important configuration values and local variables to note are:
-
-    background_image : :class:`str`, optional
+    Parameters
+    ----------
+    background_image
         The path to an image that should be the background image.
-        If not set, the background is filled with `self.background_color`
-
-    pixel_height : :class:`int`, optional
+        If not set, the background is filled with :attr:`self.background_color`
+    background
+        What :attr:`background` is set to. By default, ``None``.
+    pixel_height
         The height of the scene in pixels.
-
+    pixel_width
+        The width of the scene in pixels.
+    kwargs
+        Additional arguments (``background_color``, ``background_opacity``)
+        to be set.
     """
 
     def __init__(
         self,
-        background_image=None,
-        frame_center=ORIGIN,
-        image_mode="RGBA",
-        n_channels=4,
-        pixel_array_dtype="uint8",
-        z_buff_func=lambda m: np.round(m.get_center()[2], 2),
-        cairo_line_width_multiple=0.01,
-        use_z_index=True,
-        background=None,
-        pixel_height=None,
-        pixel_width=None,
-        frame_height=None,
-        frame_width=None,
-        frame_rate=None,
+        background_image: str | None = None,
+        frame_center: np.ndarray = ORIGIN,
+        image_mode: str = "RGBA",
+        n_channels: int = 4,
+        pixel_array_dtype: str = "uint8",
+        cairo_line_width_multiple: float = 0.01,
+        use_z_index: bool = True,
+        background: np.ndarray | None = None,
+        pixel_height: int | None = None,
+        pixel_width: int | None = None,
+        frame_height: float | None = None,
+        frame_width: float | None = None,
+        frame_rate: float | None = None,
         **kwargs,
     ):
-        """Initialises the Camera.
-
-        Parameters
-        ----------
-        background : optional
-            What self.background should be, by default None as will be set later.
-        **kwargs
-            Any local variables to be set.
-        """
         self.background_image = background_image
         self.frame_center = frame_center
         self.image_mode = image_mode
         self.n_channels = n_channels
         self.pixel_array_dtype = pixel_array_dtype
-        self.z_buff_func = z_buff_func
         self.cairo_line_width_multiple = cairo_line_width_multiple
         self.use_z_index = use_z_index
         self.background = background
@@ -105,6 +106,7 @@ class Camera:
             frame_rate = config["frame_rate"]
         self.frame_rate = frame_rate
 
+        # TODO: change this to not use kwargs.get
         for attr in ["background_color", "background_opacity"]:
             setattr(self, f"_{attr}", kwargs.get(attr, config[attr]))
 
@@ -149,7 +151,7 @@ class Camera:
         self._background_opacity = alpha
         self.init_background()
 
-    def type_or_raise(self, mobject):
+    def type_or_raise(self, mobject: Mobject):
         """Return the type of mobject, if it is a type that can be rendered.
 
         If `mobject` is an instance of a class that inherits from a class that
@@ -159,7 +161,7 @@ class Camera:
 
         Parameters
         ----------
-        mobject : :class:`~.Mobject`
+        mobject
             The object to take the type of.
 
         Notes
@@ -190,15 +192,15 @@ class Camera:
                 return _type
         raise TypeError(f"Displaying an object of class {_type} is not supported")
 
-    def reset_pixel_shape(self, new_height, new_width):
+    def reset_pixel_shape(self, new_height: float, new_width: float):
         """This method resets the height and width
         of a single pixel to the passed new_height and new_width.
 
         Parameters
         ----------
-        new_height : int, float
+        new_height
             The new height of the entire scene in pixels
-        new_width : int, float
+        new_width
             The new width of the entire scene in pixels
         """
         self.pixel_width = new_width
@@ -207,7 +209,7 @@ class Camera:
         self.resize_frame_shape()
         self.reset()
 
-    def resize_frame_shape(self, fixed_dimension=0):
+    def resize_frame_shape(self, fixed_dimension: int = 0):
         """
         Changes frame_shape to match the aspect ratio
         of the pixels, where fixed_dimension determines
@@ -216,7 +218,7 @@ class Camera:
 
         Parameters
         ----------
-        fixed_dimension : int
+        fixed_dimension
             If 0, height is scaled with respect to width
             else, width is scaled with respect to height.
         """
@@ -258,14 +260,14 @@ class Camera:
             )
             self.background[:, :] = background_rgba
 
-    def get_image(self, pixel_array=None):
+    def get_image(self, pixel_array: np.ndarray | list | tuple | None = None):
         """Returns an image from the passed
         pixel array, or from the current frame
         if the passed pixel array is none.
 
         Parameters
         ----------
-        pixel_array : np.array, list, tuple, optional
+        pixel_array
             The pixel array from which to get an image, by default None
 
         Returns
@@ -277,15 +279,17 @@ class Camera:
             pixel_array = self.pixel_array
         return Image.fromarray(pixel_array, mode=self.image_mode)
 
-    def convert_pixel_array(self, pixel_array, convert_from_floats=False):
+    def convert_pixel_array(
+        self, pixel_array: np.ndarray | list | tuple, convert_from_floats: bool = False
+    ):
         """Converts a pixel array from values that have floats in then
         to proper RGB values.
 
         Parameters
         ----------
-        pixel_array : np.array, list, tuple
+        pixel_array
             Pixel array to convert.
-        convert_from_floats : bool, optional
+        convert_from_floats
             Whether or not to convert float values to ints, by default False
 
         Returns
@@ -302,14 +306,16 @@ class Camera:
             )
         return retval
 
-    def set_pixel_array(self, pixel_array, convert_from_floats=False):
+    def set_pixel_array(
+        self, pixel_array: np.ndarray | list | tuple, convert_from_floats: bool = False
+    ):
         """Sets the pixel array of the camera to the passed pixel array.
 
         Parameters
         ----------
-        pixel_array : np.array, list, tuple
+        pixel_array
             The pixel array to convert and then set as the camera's pixel array.
-        convert_from_floats : bool, optional
+        convert_from_floats
             Whether or not to convert float values to proper RGB values, by default False
         """
         converted_array = self.convert_pixel_array(pixel_array, convert_from_floats)
@@ -322,21 +328,25 @@ class Camera:
             # Set in place
             self.pixel_array[:, :, :] = converted_array[:, :, :]
 
-    def set_background(self, pixel_array, convert_from_floats=False):
+    def set_background(
+        self, pixel_array: np.ndarray | list | tuple, convert_from_floats: bool = False
+    ):
         """Sets the background to the passed pixel_array after converting
         to valid RGB values.
 
         Parameters
         ----------
-        pixel_array : np.array, list, tuple
+        pixel_array
             The pixel array to set the background to.
-        convert_from_floats : bool, optional
+        convert_from_floats
             Whether or not to convert floats values to proper RGB valid ones, by default False
         """
         self.background = self.convert_pixel_array(pixel_array, convert_from_floats)
 
     # TODO, this should live in utils, not as a method of Camera
-    def make_background_from_func(self, coords_to_colors_func):
+    def make_background_from_func(
+        self, coords_to_colors_func: Callable[[np.ndarray], np.ndarray]
+    ):
         """
         Makes a pixel array for the background by using coords_to_colors_func to determine each pixel's color. Each input
         pixel's color. Each input to coords_to_colors_func is an (x, y) pair in space (in ordinary space coordinates; not
@@ -344,7 +354,7 @@ class Camera:
 
         Parameters
         ----------
-        coords_to_colors_func : function
+        coords_to_colors_func
             The function whose input is an (x,y) pair of coordinates and
             whose return values must be the colors for that point
 
@@ -361,7 +371,9 @@ class Camera:
 
         return self.convert_pixel_array(new_background, convert_from_floats=True)
 
-    def set_background_from_func(self, coords_to_colors_func):
+    def set_background_from_func(
+        self, coords_to_colors_func: Callable[[np.ndarray], np.ndarray]
+    ):
         """
         Sets the background to a pixel array using coords_to_colors_func to determine each pixel's color. Each input
         pixel's color. Each input to coords_to_colors_func is an (x, y) pair in space (in ordinary space coordinates; not
@@ -369,7 +381,7 @@ class Camera:
 
         Parameters
         ----------
-        coords_to_colors_func : function
+        coords_to_colors_func
             The function whose input is an (x,y) pair of coordinates and
             whose return values must be the colors for that point
         """
@@ -383,7 +395,7 @@ class Camera:
         -------
         Camera
             The camera object after setting the pixel array.
-        """ ""
+        """
         self.set_pixel_array(self.background)
         return self
 
@@ -394,20 +406,20 @@ class Camera:
 
     def get_mobjects_to_display(
         self,
-        mobjects,
-        include_submobjects=True,
-        excluded_mobjects=None,
+        mobjects: Iterable[Mobject],
+        include_submobjects: bool = True,
+        excluded_mobjects: list | None = None,
     ):
         """Used to get the list of mobjects to display
         with the camera.
 
         Parameters
         ----------
-        mobjects : Mobject
+        mobjects
             The Mobjects
-        include_submobjects : bool, optional
+        include_submobjects
             Whether or not to include the submobjects of mobjects, by default True
-        excluded_mobjects : list, optional
+        excluded_mobjects
             Any mobjects to exclude, by default None
 
         Returns
@@ -427,15 +439,15 @@ class Camera:
                     use_z_index=self.use_z_index,
                 )
                 mobjects = list_difference_update(mobjects, all_excluded)
-        return mobjects
+        return list(mobjects)
 
-    def is_in_frame(self, mobject):
+    def is_in_frame(self, mobject: Mobject):
         """Checks whether the passed mobject is in
         frame or not.
 
         Parameters
         ----------
-        mobject : Mobject
+        mobject
             The mobject for which the checking needs to be done.
 
         Returns
@@ -472,7 +484,7 @@ class Camera:
         """
         return self.capture_mobjects([mobject], **kwargs)
 
-    def capture_mobjects(self, mobjects, **kwargs):
+    def capture_mobjects(self, mobjects: Iterable[Mobject], **kwargs):
         """Capture mobjects by printing them on :attr:`pixel_array`.
 
         This is the essential function that converts the contents of a Scene
@@ -480,10 +492,10 @@ class Camera:
 
         Parameters
         ----------
-        mobjects : :class:`~.Mobject`
+        mobjects
             Mobjects to capture.
 
-        kwargs : Any
+        kwargs
             Keyword arguments to be passed to :meth:`get_mobjects_to_display`.
 
         Notes
@@ -507,13 +519,13 @@ class Camera:
     # NOTE: None of the methods below have been mentioned outside of their definitions. Their DocStrings are not as
     # detailed as possible.
 
-    def get_cached_cairo_context(self, pixel_array):
+    def get_cached_cairo_context(self, pixel_array: np.ndarray):
         """Returns the cached cairo context of the passed
         pixel array if it exists, and None if it doesn't.
 
         Parameters
         ----------
-        pixel_array : np.array
+        pixel_array
             The pixel array to check.
 
         Returns
@@ -523,19 +535,19 @@ class Camera:
         """
         return self.pixel_array_to_cairo_context.get(id(pixel_array), None)
 
-    def cache_cairo_context(self, pixel_array, ctx):
+    def cache_cairo_context(self, pixel_array: np.ndarray, ctx: cairo.Context):
         """Caches the passed Pixel array into a Cairo Context
 
         Parameters
         ----------
-        pixel_array : np.array
+        pixel_array
             The pixel array to cache
-        ctx : cairo.Context
+        ctx
             The context to cache it into.
         """
         self.pixel_array_to_cairo_context[id(pixel_array)] = ctx
 
-    def get_cairo_context(self, pixel_array):
+    def get_cairo_context(self, pixel_array: np.ndarray):
         """Returns the cairo context for a pixel array after
         caching it to self.pixel_array_to_cairo_context
         If that array has already been cached, it returns the
@@ -543,7 +555,7 @@ class Camera:
 
         Parameters
         ----------
-        pixel_array : np.array
+        pixel_array
             The Pixel array to get the cairo context of.
 
         Returns
@@ -580,14 +592,16 @@ class Camera:
         self.cache_cairo_context(pixel_array, ctx)
         return ctx
 
-    def display_multiple_vectorized_mobjects(self, vmobjects, pixel_array):
+    def display_multiple_vectorized_mobjects(
+        self, vmobjects: list, pixel_array: np.ndarray
+    ):
         """Displays multiple VMobjects in the pixel_array
 
         Parameters
         ----------
-        vmobjects : list
+        vmobjects
             list of VMobjects to display
-        pixel_array : np.array
+        pixel_array
             The pixel array
         """
         if len(vmobjects) == 0:
@@ -602,29 +616,31 @@ class Camera:
                     pixel_array,
                 )
 
-    def display_multiple_non_background_colored_vmobjects(self, vmobjects, pixel_array):
+    def display_multiple_non_background_colored_vmobjects(
+        self, vmobjects: list, pixel_array: np.ndarray
+    ):
         """Displays multiple VMobjects in the cairo context, as long as they don't have
         background colors.
 
         Parameters
         ----------
-        vmobjects : list
+        vmobjects
             list of the VMobjects
-        pixel_array : np.ndarray
+        pixel_array
             The Pixel array to add the VMobjects to.
         """
         ctx = self.get_cairo_context(pixel_array)
         for vmobject in vmobjects:
             self.display_vectorized(vmobject, ctx)
 
-    def display_vectorized(self, vmobject, ctx):
+    def display_vectorized(self, vmobject: VMobject, ctx: cairo.Context):
         """Displays a VMobject in the cairo context
 
         Parameters
         ----------
-        vmobject : VMobject
+        vmobject
             The Vectorized Mobject to display
-        ctx : cairo.Context
+        ctx
             The cairo context to use.
 
         Returns
@@ -638,14 +654,14 @@ class Camera:
         self.apply_stroke(ctx, vmobject)
         return self
 
-    def set_cairo_context_path(self, ctx, vmobject):
+    def set_cairo_context_path(self, ctx: cairo.Context, vmobject: VMobject):
         """Sets a path for the cairo context with the vmobject passed
 
         Parameters
         ----------
-        ctx : cairo.Context
+        ctx
             The cairo context
-        vmobject : VMobject
+        vmobject
             The VMobject
 
         Returns
@@ -672,16 +688,18 @@ class Camera:
                 ctx.close_path()
         return self
 
-    def set_cairo_context_color(self, ctx, rgbas, vmobject):
+    def set_cairo_context_color(
+        self, ctx: cairo.Context, rgbas: np.ndarray, vmobject: VMobject
+    ):
         """Sets the color of the cairo context
 
         Parameters
         ----------
-        ctx : cairo.Context
+        ctx
             The cairo context
-        rgbas : np.ndarray
+        rgbas
             The RGBA array with which to color the context.
-        vmobject : VMobject
+        vmobject
             The VMobject with which to set the color.
 
         Returns
@@ -704,14 +722,14 @@ class Camera:
             ctx.set_source(pat)
         return self
 
-    def apply_fill(self, ctx, vmobject):
+    def apply_fill(self, ctx: cairo.Context, vmobject: VMobject):
         """Fills the cairo context
 
         Parameters
         ----------
-        ctx : cairo.Context
+        ctx
             The cairo context
-        vmobject : VMobject
+        vmobject
             The VMobject
 
         Returns
@@ -723,16 +741,18 @@ class Camera:
         ctx.fill_preserve()
         return self
 
-    def apply_stroke(self, ctx, vmobject, background=False):
+    def apply_stroke(
+        self, ctx: cairo.Context, vmobject: VMobject, background: bool = False
+    ):
         """Applies a stroke to the VMobject in the cairo context.
 
         Parameters
         ----------
-        ctx : cairo.Context
+        ctx
             The cairo context
-        vmobject : VMobject
+        vmobject
             The VMobject
-        background : bool, optional
+        background
             Whether or not to consider the background when applying this
             stroke width, by default False
 
@@ -755,18 +775,20 @@ class Camera:
             # This ensures lines have constant width as you zoom in on them.
             * (self.frame_width / self.frame_width),
         )
+        if vmobject.joint_type != LineJointType.AUTO:
+            ctx.set_line_join(LINE_JOIN_MAP[vmobject.joint_type])
         ctx.stroke_preserve()
         return self
 
-    def get_stroke_rgbas(self, vmobject, background=False):
+    def get_stroke_rgbas(self, vmobject: VMobject, background: bool = False):
         """Gets the RGBA array for the stroke of the passed
         VMobject.
 
         Parameters
         ----------
-        vmobject : VMobject
+        vmobject
             The VMobject
-        background : bool, optional
+        background
             Whether or not to consider the background when getting the stroke
             RGBAs, by default False
 
@@ -777,12 +799,12 @@ class Camera:
         """
         return vmobject.get_stroke_rgbas(background)
 
-    def get_fill_rgbas(self, vmobject):
+    def get_fill_rgbas(self, vmobject: VMobject):
         """Returns the RGBA array of the fill of the passed VMobject
 
         Parameters
         ----------
-        vmobject : VMobject
+        vmobject
             The VMobject
 
         Returns
@@ -808,14 +830,16 @@ class Camera:
             setattr(self, bcvd, BackgroundColoredVMobjectDisplayer(self))
         return getattr(self, bcvd)
 
-    def display_multiple_background_colored_vmobjects(self, cvmobjects, pixel_array):
+    def display_multiple_background_colored_vmobjects(
+        self, cvmobjects: list, pixel_array: np.ndarray
+    ):
         """Displays multiple vmobjects that have the same color as the background.
 
         Parameters
         ----------
-        cvmobjects : list
+        cvmobjects
             List of Colored VMobjects
-        pixel_array : np.array
+        pixel_array
             The pixel array.
 
         Returns
@@ -833,14 +857,16 @@ class Camera:
     # NOTE: Out of the following methods, only `transform_points_pre_display` and `points_to_pixel_coords` have been mentioned outside of their definitions.
     # As a result, the other methods do not have as detailed docstrings as would be preferred.
 
-    def display_multiple_point_cloud_mobjects(self, pmobjects, pixel_array):
+    def display_multiple_point_cloud_mobjects(
+        self, pmobjects: list, pixel_array: np.ndarray
+    ):
         """Displays multiple PMobjects by modifying the passed pixel array.
 
         Parameters
         ----------
-        pmobjects : list
+        pmobjects
             List of PMobjects
-        pixel_array : np.array
+        pixel_array
             The pixel array to modify.
         """
         for pmobject in pmobjects:
@@ -852,20 +878,27 @@ class Camera:
                 pixel_array,
             )
 
-    def display_point_cloud(self, pmobject, points, rgbas, thickness, pixel_array):
+    def display_point_cloud(
+        self,
+        pmobject: PMobject,
+        points: list,
+        rgbas: np.ndarray,
+        thickness: float,
+        pixel_array: np.ndarray,
+    ):
         """Displays a PMobject by modifying the Pixel array suitably..
         TODO: Write a description for the rgbas argument.
         Parameters
         ----------
-        pmobject : PMobject
+        pmobject
             Point Cloud Mobject
-        points : list
+        points
             The points to display in the point cloud mobject
-        rgbas : np.array
+        rgbas
 
-        thickness : int, float
+        thickness
             The thickness of each point of the PMobject
-        pixel_array : np.array
+        pixel_array
             The pixel array to modify.
 
         """
@@ -896,27 +929,31 @@ class Camera:
         new_pa[indices] = rgbas
         pixel_array[:, :] = new_pa.reshape((ph, pw, rgba_len))
 
-    def display_multiple_image_mobjects(self, image_mobjects, pixel_array):
+    def display_multiple_image_mobjects(
+        self, image_mobjects: list, pixel_array: np.ndarray
+    ):
         """Displays multiple image mobjects by modifying the passed pixel_array.
 
         Parameters
         ----------
-        image_mobjects : list
+        image_mobjects
             list of ImageMobjects
-        pixel_array : np.array
+        pixel_array
             The pixel array to modify.
         """
         for image_mobject in image_mobjects:
             self.display_image_mobject(image_mobject, pixel_array)
 
-    def display_image_mobject(self, image_mobject: AbstractImageMobject, pixel_array):
+    def display_image_mobject(
+        self, image_mobject: AbstractImageMobject, pixel_array: np.ndarray
+    ):
         """Displays an ImageMobject by changing the pixel_array suitably.
 
         Parameters
         ----------
-        image_mobject : ImageMobject
+        image_mobject
             The imageMobject to display
-        pixel_array : np.ndarray
+        pixel_array
             The Pixel array to put the imagemobject in.
         """
         corner_coords = self.points_to_pixel_coords(image_mobject, image_mobject.points)
@@ -966,26 +1003,26 @@ class Camera:
         # Paint on top of existing pixel array
         self.overlay_PIL_image(pixel_array, full_image)
 
-    def overlay_rgba_array(self, pixel_array, new_array):
+    def overlay_rgba_array(self, pixel_array: np.ndarray, new_array: np.ndarray):
         """Overlays an RGBA array on top of the given Pixel array.
 
         Parameters
         ----------
-        pixel_array : np.array
+        pixel_array
             The original pixel array to modify.
-        new_array : np.array
+        new_array
             The new pixel array to overlay.
         """
         self.overlay_PIL_image(pixel_array, self.get_image(new_array))
 
-    def overlay_PIL_image(self, pixel_array, image):
+    def overlay_PIL_image(self, pixel_array: np.ndarray, image: Image):
         """Overlays a PIL image on the passed pixel array.
 
         Parameters
         ----------
-        pixel_array : np.ndarray
+        pixel_array
             The Pixel array
-        image : PIL.Image
+        image
             The Image to overlay.
         """
         pixel_array[:, :] = np.array(
@@ -993,13 +1030,13 @@ class Camera:
             dtype="uint8",
         )
 
-    def adjust_out_of_range_points(self, points):
+    def adjust_out_of_range_points(self, points: np.ndarray):
         """If any of the points in the passed array are out of
         the viable range, they are adjusted suitably.
 
         Parameters
         ----------
-        points : np.array
+        points
             The points to adjust
 
         Returns
@@ -1061,13 +1098,13 @@ class Camera:
         result[:, 1] = shifted_points[:, 1] * height_mult + height_add
         return result.astype("int")
 
-    def on_screen_pixels(self, pixel_coords):
+    def on_screen_pixels(self, pixel_coords: np.ndarray):
         """Returns array of pixels that are on the screen from a given
         array of pixel_coordinates
 
         Parameters
         ----------
-        pixel_coords : np.array
+        pixel_coords
             The pixel coords to check.
 
         Returns
@@ -1085,12 +1122,12 @@ class Camera:
             ],
         )
 
-    def adjusted_thickness(self, thickness):
+    def adjusted_thickness(self, thickness: float):
         """
 
         Parameters
         ----------
-        thickness : int, float
+        thickness
 
         Returns
         -------
@@ -1103,12 +1140,12 @@ class Camera:
         factor = big_sum / this_sum
         return 1 + (thickness - 1) * factor
 
-    def get_thickening_nudges(self, thickness):
+    def get_thickening_nudges(self, thickness: float):
         """
 
         Parameters
         ----------
-        thickness : int, float
+        thickness
 
         Returns
         -------
@@ -1119,15 +1156,15 @@ class Camera:
         _range = list(range(-thickness // 2 + 1, thickness // 2 + 1))
         return np.array(list(it.product(_range, _range)))
 
-    def thickened_coordinates(self, pixel_coords, thickness):
+    def thickened_coordinates(self, pixel_coords: np.ndarray, thickness: float):
         """Returns thickened coordinates for a passed array of pixel coords and
         a thickness to thicken by.
 
         Parameters
         ----------
-        pixel_coords : np.array
+        pixel_coords
             Pixel coordinates
-        thickness : int, float
+        thickness
             Thickness
 
         Returns
@@ -1178,11 +1215,11 @@ class Camera:
 # NOTE: The methods of the following class have not been mentioned outside of their definitions.
 # Their DocStrings are not as detailed as preferred.
 class BackgroundColoredVMobjectDisplayer:
-    def __init__(self, camera):
+    def __init__(self, camera: Camera):
         """
         Parameters
         ----------
-        camera : Camera
+        camera
             Camera object to use.
         """
         self.camera = camera
@@ -1195,22 +1232,22 @@ class BackgroundColoredVMobjectDisplayer:
 
     def resize_background_array(
         self,
-        background_array,
-        new_width,
-        new_height,
-        mode="RGBA",
+        background_array: np.ndarray,
+        new_width: float,
+        new_height: float,
+        mode: str = "RGBA",
     ):
         """Resizes the pixel array representing the background.
 
         Parameters
         ----------
-        background_array : np.array
+        background_array
             The pixel
-        new_width : int, float
+        new_width
             The new width of the background
-        new_height : int, float
+        new_height
             The new height of the background
-        mode : str, optional
+        mode
             The PIL image mode, by default "RGBA"
 
         Returns
@@ -1223,14 +1260,16 @@ class BackgroundColoredVMobjectDisplayer:
         resized_image = image.resize((new_width, new_height))
         return np.array(resized_image)
 
-    def resize_background_array_to_match(self, background_array, pixel_array):
+    def resize_background_array_to_match(
+        self, background_array: np.ndarray, pixel_array: np.ndarray
+    ):
         """Resizes the background array to match the passed pixel array.
 
         Parameters
         ----------
-        background_array : np.array
+        background_array
             The prospective pixel array.
-        pixel_array : np.array
+        pixel_array
             The pixel array whose width and height should be matched.
 
         Returns
@@ -1271,12 +1310,12 @@ class BackgroundColoredVMobjectDisplayer:
         self.file_name_to_pixel_array_map[image_key] = back_array
         return back_array
 
-    def display(self, *cvmobjects):
+    def display(self, *cvmobjects: VMobject):
         """Displays the colored VMobjects.
 
         Parameters
         ----------
-        *cvmobjects : VMobject
+        *cvmobjects
             The VMobjects
 
         Returns
