@@ -5,8 +5,11 @@ from __future__ import annotations
 __all__ = ["ThreeDCamera"]
 
 
+from typing import Callable
+
 import numpy as np
 
+from manim.mobject.mobject import Mobject
 from manim.mobject.three_d.three_d_utils import (
     get_3d_vmob_end_corner,
     get_3d_vmob_end_corner_unit_normal,
@@ -43,8 +46,6 @@ class ThreeDCamera(Camera):
 
         Parameters
         ----------
-        *args
-            Any argument of Camera
         *kwargs
             Any keyword argument of Camera.
         """
@@ -197,52 +198,52 @@ class ThreeDCamera(Camera):
         """
         return self.zoom_tracker.get_value()
 
-    def set_phi(self, value):
+    def set_phi(self, value: float):
         """Sets the polar angle i.e the angle between Z_AXIS and Camera through ORIGIN in radians.
 
         Parameters
         ----------
-        value : int, float
+        value
             The new value of the polar angle in radians.
         """
         self.phi_tracker.set_value(value)
 
-    def set_theta(self, value):
+    def set_theta(self, value: float):
         """Sets the azimuthal angle i.e the angle that spins the camera around Z_AXIS in radians.
 
         Parameters
         ----------
-        value : int, float
+        value
             The new value of the azimuthal angle in radians.
         """
         self.theta_tracker.set_value(value)
 
-    def set_focal_distance(self, value):
+    def set_focal_distance(self, value: float):
         """Sets the focal_distance of the Camera.
 
         Parameters
         ----------
-        value : int, float
+        value
             The focal_distance of the Camera.
         """
         self.focal_distance_tracker.set_value(value)
 
-    def set_gamma(self, value):
+    def set_gamma(self, value: float):
         """Sets the angle of rotation of the camera about the vector from the ORIGIN to the Camera.
 
         Parameters
         ----------
-        value : int, float
+        value
             The new angle of rotation of the camera.
         """
         self.gamma_tracker.set_value(value)
 
-    def set_zoom(self, value):
+    def set_zoom(self, value: float):
         """Sets the zoom amount of the camera.
 
         Parameters
         ----------
-        value : int, float
+        value
             The zoom amount of the camera.
         """
         self.zoom_tracker.set_value(value)
@@ -284,13 +285,13 @@ class ThreeDCamera(Camera):
             result = np.dot(matrix, result)
         return result
 
-    def project_points(self, points):
+    def project_points(self, points: np.ndarray | list):
         """Applies the current rotation_matrix as a projection
         matrix to the passed array of points.
 
         Parameters
         ----------
-        points : np.array, list
+        points
             The list of points to project.
 
         Returns
@@ -321,13 +322,13 @@ class ThreeDCamera(Camera):
             points[:, i] *= factor * zoom
         return points
 
-    def project_point(self, point):
+    def project_point(self, point: list | np.ndarray):
         """Applies the current rotation_matrix as a projection
         matrix to the passed point.
 
         Parameters
         ----------
-        point : list, np.array
+        point
             The point to project.
 
         Returns
@@ -357,7 +358,10 @@ class ThreeDCamera(Camera):
             return self.project_points(points)
 
     def add_fixed_orientation_mobjects(
-        self, *mobjects, use_static_center_func=False, center_func=None
+        self,
+        *mobjects: Mobject,
+        use_static_center_func: bool = False,
+        center_func: Callable[[], np.ndarray] | None = None,
     ):
         """This method allows the mobject to have a fixed orientation,
         even when the camera moves around.
@@ -367,12 +371,12 @@ class ThreeDCamera(Camera):
 
         Parameters
         ----------
-        *mobjects : Mobject
+        *mobjects
             The mobject whose orientation must be fixed.
-        use_static_center_func : bool, optional
+        use_static_center_func
             Whether or not to use the function that takes the mobject's
             center as centerpoint, by default False
-        center_func : func, optional
+        center_func
             The function which returns the centerpoint
             with respect to which the mobject will be oriented, by default None
         """
@@ -392,7 +396,7 @@ class ThreeDCamera(Camera):
             for submob in mobject.get_family():
                 self.fixed_orientation_mobjects[submob] = func
 
-    def add_fixed_in_frame_mobjects(self, *mobjects):
+    def add_fixed_in_frame_mobjects(self, *mobjects: Mobject):
         """This method allows the mobject to have a fixed position,
         even when the camera moves around.
         E.G If it was passed through this method, at the top of the frame, it
@@ -402,34 +406,34 @@ class ThreeDCamera(Camera):
 
         Parameters
         ----------
-        **mobjects : Mobject
+        **mobjects
             The mobject to fix in frame.
         """
         for mobject in extract_mobject_family_members(mobjects):
             self.fixed_in_frame_mobjects.add(mobject)
 
-    def remove_fixed_orientation_mobjects(self, *mobjects):
+    def remove_fixed_orientation_mobjects(self, *mobjects: Mobject):
         """If a mobject was fixed in its orientation by passing it through
         :meth:`.add_fixed_orientation_mobjects`, then this undoes that fixing.
         The Mobject will no longer have a fixed orientation.
 
         Parameters
         ----------
-        mobjects : :class:`Mobject`
+        mobjects
             The mobjects whose orientation need not be fixed any longer.
         """
         for mobject in extract_mobject_family_members(mobjects):
             if mobject in self.fixed_orientation_mobjects:
                 del self.fixed_orientation_mobjects[mobject]
 
-    def remove_fixed_in_frame_mobjects(self, *mobjects):
+    def remove_fixed_in_frame_mobjects(self, *mobjects: Mobject):
         """If a mobject was fixed in frame by passing it through
         :meth:`.add_fixed_in_frame_mobjects`, then this undoes that fixing.
         The Mobject will no longer be fixed in frame.
 
         Parameters
         ----------
-        mobjects : :class:`Mobject`
+        mobjects
             The mobjects which need not be fixed in frame any longer.
         """
         for mobject in extract_mobject_family_members(mobjects):
