@@ -592,14 +592,12 @@ class NumberLine(Line):
         self, label_tex: str | float | VMobject, **kwargs
     ) -> VMobject:
         """Checks if the label is a :class:`~.VMobject`, otherwise, creates a
-        label according to the ``label_constructor``.
+        label according to :attr:`label_constructor`.
 
         Parameters
         ----------
         label_tex
             The label to be compared against the above types.
-        label_constructor
-            The VMobject class used to construct the label.
 
         Returns
         -------
