@@ -31,6 +31,7 @@ from manim.mobject.opengl.opengl_compatibility import ConvertToOpenGL
 from manim.mobject.opengl.opengl_mobject import OpenGLMobject
 from manim.mobject.types.vectorized_mobject import VGroup, VMobject
 from manim.utils.color import *
+from manim.utils.color import Colors
 from manim.utils.deprecation import deprecated_params
 from manim.utils.iterables import tuplify
 from manim.utils.space_ops import normalize, perpendicular_bisector, z_to_vector
@@ -46,16 +47,31 @@ class Surface(VGroup, metaclass=ConvertToOpenGL):
 
     Parameters
     ----------
-    func :
-        The function that defines the surface.
-    u_range :
+    func
+        The function defining the :class:`Surface`.
+    u_range
         The range of the ``u`` variable: ``(u_min, u_max)``.
-    v_range :
+    v_range
         The range of the ``v`` variable: ``(v_min, v_max)``.
-    resolution :
-        The number of samples taken of the surface. A tuple
-        can be used to define different resolutions for ``u`` and
-        ``v`` respectively.
+    resolution
+        The number of samples taken of the :class:`Surface`. A tuple can be
+        used to define different resolutions for ``u`` and ``v`` respectively.
+    fill_color
+        The color of the :class:`Surface`. Ignored if ``checkerboard_colors``
+        is set.
+    fill_opacity
+        The opacity of the :class:`Surface`, from 0 being fully transparent
+        to 1 being fully opaque. Defaults to 1.
+    checkerboard_colors
+        Colors individual faces alternating colors. Overrides ``fill_color``.
+    stroke_color
+        Color of the stroke surrounding each face of :class:`Surface`.
+    stroke_width
+        Width of the stroke surrounding each face of :class:`Surface`.
+        Defaults to 0.5.
+    should_make_jagged
+        Changes the anchor mode of the Bézier curves from smooth to jagged.
+        Defaults to ``False``.
 
     Examples
     --------
@@ -161,6 +177,22 @@ class Surface(VGroup, metaclass=ConvertToOpenGL):
             self.set_fill_by_checkerboard(*self.checkerboard_colors)
 
     def set_fill_by_checkerboard(self, *colors, opacity=None):
+        """Sets the fill_color of each face of :class:`Surface` in
+        an alternating pattern.
+
+        Parameters
+        ----------
+        colors
+            List of colors for alternating pattern.
+        opacity
+            The fill_opacity of :class:`Surface`, from 0 being fully transparent
+            to 1 being fully opaque.
+
+        Returns
+        -------
+        :class:`~.Surface`
+            The parametric surface with an alternating pattern.
+        """
         n_colors = len(colors)
         for face in self:
             c_index = (face.u_index + face.v_index) % n_colors
@@ -175,16 +207,19 @@ class Surface(VGroup, metaclass=ConvertToOpenGL):
         axis: int = 2,
         **kwargs,
     ):
-        """Sets the color of each mobject of a parametric surface to a color relative to its axis-value
+        """Sets the color of each mobject of a parametric surface to a color
+        relative to its axis-value.
 
         Parameters
         ----------
-        axes :
-            The axes for the parametric surface, which will be used to map axis-values to colors.
-        colorscale :
-            A list of colors, ordered from lower axis-values to higher axis-values. If a list of tuples is passed
-            containing colors paired with numbers, then those numbers will be used as the pivots.
-        axis :
+        axes
+            The axes for the parametric surface, which will be used to map
+            axis-values to colors.
+        colorscale
+            A list of colors, ordered from lower axis-values to higher axis-values.
+            If a list of tuples is passed containing colors paired with numbers,
+            then those numbers will be used as the pivots.
+        axis
             The chosen axis to use for the color mapping. (0 = x, 1 = y, 2 = z)
 
         Returns
@@ -268,9 +303,9 @@ class Surface(VGroup, metaclass=ConvertToOpenGL):
                             new_colors[i],
                             color_index,
                         )
-                        if config.renderer == "opengl":
+                        if config.renderer == RendererType.OPENGL:
                             mob.set_color(mob_color, recurse=False)
-                        else:
+                        elif config.renderer == RendererType.CAIRO:
                             mob.set_color(mob_color, family=False)
                         break
 
@@ -281,10 +316,24 @@ class Surface(VGroup, metaclass=ConvertToOpenGL):
 
 
 class Sphere(Surface):
-    """A mobject representing a three-dimensional sphere.
+    """An three-dimensional sphere.
+
+    Parameters
+    ----------
+    center
+        Center of the :class:`Sphere`.
+    radius
+        The radius of the :class:`Sphere`.
+    resolution
+        The number of samples taken of the :class:`Sphere`. A tuple can be used
+        to define different resolutions for ``u`` and ``v`` respectively.
+    u_range
+        The range of the ``u`` variable: ``(u_min, u_max)``.
+    v_range
+        The range of the ``v`` variable: ``(v_min, v_max)``.
 
     Examples
-    ---------
+    --------
 
     .. manim:: ExampleSphere
         :save_last_frame:
@@ -318,9 +367,9 @@ class Sphere(Surface):
         v_range=(0, PI),
         **kwargs,
     ):
-        if config.renderer == "opengl":
+        if config.renderer == RendererType.OPENGL:
             res_value = (101, 51)
-        else:
+        elif config.renderer == RendererType.CAIRO:
             res_value = (24, 12)
 
         resolution = resolution if resolution is not None else res_value
@@ -347,13 +396,16 @@ class Dot3D(Sphere):
     """A spherical dot.
 
     Parameters
-    --------
-    point : Union[:class:`list`, :class:`numpy.ndarray`], optional
+    ----------
+    point
         The location of the dot.
-    radius : :class:`float`, optional
+    radius
         The radius of the dot.
-    color : :class:`~.Colors`, optional
-        The color of the :class:`Dot3D`
+    color
+        The color of the :class:`Dot3D`.
+    resolution
+        The number of samples taken of the :class:`Dot3D`. A tuple can be
+        used to define different resolutions for ``u`` and ``v`` respectively.
 
     Examples
     --------
@@ -374,9 +426,9 @@ class Dot3D(Sphere):
 
     def __init__(
         self,
-        point=ORIGIN,
-        radius=DEFAULT_DOT_RADIUS,
-        color=WHITE,
+        point: list | np.ndarray = ORIGIN,
+        radius: float = DEFAULT_DOT_RADIUS,
+        color: Colors = WHITE,
         resolution=(8, 8),
         **kwargs,
     ):
@@ -385,6 +437,35 @@ class Dot3D(Sphere):
 
 
 class Cube(VGroup):
+    """A three-dimensional cube.
+
+    Parameters
+    ----------
+    side_length
+        Length of each side of the :class:`Cube`.
+    fill_opacity
+        The opacity of the :class:`Cube`, from 0 being fully transparent to 1 being
+        fully opaque. Defaults to 0.75.
+    fill_color
+        The color of the :class:`Cube`.
+    stroke_width
+        The width of the stroke surrounding each face of the :class:`Cube`.
+
+    Examples
+    --------
+
+    .. manim:: CubeExample
+        :save_last_frame:
+
+        class CubeExample(ThreeDScene):
+            def construct(self):
+                self.set_camera_orientation(phi=75*DEGREES, theta=-45*DEGREES)
+
+                axes = ThreeDAxes()
+                cube = Cube(side_length=3, fill_opacity=0.7, fill_color=BLUE)
+                self.add(cube)
+    """
+
     def __init__(
         self,
         side_length=2,
@@ -417,7 +498,13 @@ class Cube(VGroup):
 
 
 class Prism(Cube):
-    """A cuboid.
+    """A right rectangular prism (or rectangular cuboid).
+    Defined by the length of each side in ``[x, y, z]`` format.
+
+    Parameters
+    ----------
+    dimensions
+        Dimensions of the :class:`Prism` in ``[x, y, z]`` format.
 
     Examples
     --------
@@ -450,6 +537,24 @@ class Cone(Surface):
     height) The spherical radius, r, is calculated using the pythagorean
     theorem.
 
+    Parameters
+    ----------
+    base_radius
+        The base radius from which the cone tapers.
+    height
+        The height measured from the plane formed by the base_radius to
+        the apex of the cone.
+    direction
+        The direction of the apex.
+    show_base
+        Whether to show the base plane or not.
+    v_range
+        The azimuthal angle to start and end at.
+    u_min
+        The radius at the apex.
+    checkerboard_colors
+        Show checkerboard grid texture on the cone.
+
     Examples
     --------
     .. manim:: ExampleCone
@@ -461,34 +566,17 @@ class Cone(Surface):
                 cone = Cone(direction=X_AXIS+Y_AXIS+2*Z_AXIS, resolution=8)
                 self.set_camera_orientation(phi=5*PI/11, theta=PI/9)
                 self.add(axes, cone)
-
-    Parameters
-    --------
-    base_radius : :class:`float`
-        The base radius from which the cone tapers.
-    height : :class:`float`
-        The height measured from the plane formed by the base_radius to the apex of the cone.
-    direction : :class:`numpy.array`
-        The direction of the apex.
-    show_base : :class:`bool`
-        Whether to show the base plane or not.
-    v_range : :class:`Sequence[float]`
-        The azimuthal angle to start and end at.
-    u_min : :class:`float`
-        The radius at the apex.
-    checkerboard_colors : :class:`bool`
-        Show checkerboard grid texture on the cone.
     """
 
     def __init__(
         self,
-        base_radius=1,
-        height=1,
-        direction=Z_AXIS,
-        show_base=False,
-        v_range=[0, TAU],
-        u_min=0,
-        checkerboard_colors=False,
+        base_radius: float = 1,
+        height: float = 1,
+        direction: np.ndarray = Z_AXIS,
+        show_base: bool = False,
+        v_range: Sequence[float] = [0, TAU],
+        u_min: float = 0,
+        checkerboard_colors: bool = False,
         **kwargs,
     ):
         self.direction = direction
@@ -517,13 +605,14 @@ class Cone(Surface):
 
         self._rotate_to_direction()
 
-    def func(self, u, v):
+    def func(self, u: float, v: float):
         """Converts from spherical coordinates to cartesian.
+
         Parameters
-        ---------
-        u : :class:`float`
+        ----------
+        u
             The radius.
-        v : :class:`float`
+        v
             The azimuthal angle.
         """
         r = u
@@ -570,18 +659,48 @@ class Cone(Surface):
         self._current_phi = phi
 
     def set_direction(self, direction):
+        """Changes the direction of the apex of the :class:`Cone`.
+
+        Parameters
+        ----------
+        direction : :class:`numpy.array`
+            The direction of the apex.
+        """
         self.direction = direction
         self._rotate_to_direction()
 
     def get_direction(self):
+        """Returns the current direction of the apex of the :class:`Cone`.
+
+        Returns
+        -------
+        direction : :class:`numpy.array`
+            The direction of the apex.
+        """
         return self.direction
 
 
 class Cylinder(Surface):
     """A cylinder, defined by its height, radius and direction,
 
+    Parameters
+    ----------
+    radius
+        The radius of the cylinder.
+    height
+        The height of the cylinder.
+    direction
+        The direction of the central axis of the cylinder.
+    v_range
+        The height along the height axis (given by direction) to start and end on.
+    show_ends
+        Whether to show the end caps or not.
+    resolution
+        The number of samples taken of the :class:`Cylinder`. A tuple can be used
+        to define different resolutions for ``u`` and ``v`` respectively.
+
     Examples
-    ---------
+    --------
     .. manim:: ExampleCylinder
         :save_last_frame:
 
@@ -591,28 +710,15 @@ class Cylinder(Surface):
                 cylinder = Cylinder(radius=2, height=3)
                 self.set_camera_orientation(phi=75 * DEGREES, theta=30 * DEGREES)
                 self.add(axes, cylinder)
-
-    Parameters
-    ---------
-    radius : :class:`float`
-        The radius of the cylinder.
-    height : :class:`float`
-        The height of the cylinder.
-    direction : :class:`numpy.array`
-        The direction of the central axis of the cylinder.
-    v_range : :class:`Sequence[float]`
-        The height along the height axis (given by direction) to start and end on.
-    show_ends : :class:`bool`
-        Whether to show the end caps or not.
     """
 
     def __init__(
         self,
-        radius=1,
-        height=2,
-        direction=Z_AXIS,
-        v_range=[0, TAU],
-        show_ends=True,
+        radius: float = 1,
+        height: float = 2,
+        direction: np.ndarray = Z_AXIS,
+        v_range: Sequence[float] = [0, TAU],
+        show_ends: bool = True,
         resolution=(24, 24),
         **kwargs,
     ):
@@ -631,13 +737,14 @@ class Cylinder(Surface):
         self._current_theta = 0
         self.set_direction(direction)
 
-    def func(self, u, v):
+    def func(self, u: float, v: float):
         """Converts from cylindrical coordinates to cartesian.
+
         Parameters
-        ---------
-        u : :class:`float`
+        ----------
+        u
             The height.
-        v : :class:`float`
+        v
             The azimuthal angle.
         """
         height = u
@@ -647,8 +754,13 @@ class Cylinder(Surface):
 
     def add_bases(self):
         """Adds the end caps of the cylinder."""
-        color = self.color if config["renderer"] == "opengl" else self.fill_color
-        opacity = self.opacity if config["renderer"] == "opengl" else self.fill_opacity
+        if config.renderer == RendererType.OPENGL:
+            color = self.color
+            opacity = self.opacity
+        elif config.renderer == RendererType.CAIRO:
+            color = self.fill_color
+            opacity = self.fill_opacity
+
         self.base_top = Circle(
             radius=self.radius,
             color=color,
@@ -701,21 +813,45 @@ class Cylinder(Surface):
         self._current_phi = phi
 
     def set_direction(self, direction):
+        """Sets the direction of the central axis of the :class:`Cylinder`.
+
+        Parameters
+        ----------
+        direction
+            The direction of the central axis of the :class:`Cylinder`.
+        """
         # if get_norm(direction) is get_norm(self.direction):
         #     pass
         self.direction = direction
         self._rotate_to_direction()
 
     def get_direction(self):
-        """Returns the direction of the central axis of the cylinder."""
+        """Returns the direction of the central axis of the :class:`Cylinder`.
+
+        Returns
+        -------
+        direction
+            The direction of the central axis of the :class:`Cylinder`.
+        """
         return self.direction
 
 
 class Line3D(Cylinder):
     """A cylindrical line, for use in ThreeDScene.
 
+    Parameters
+    ----------
+    start
+        The start point of the line.
+    end
+        The end point of the line.
+    thickness
+        The thickness of the line.
+    color
+        The color of the line.
+
     Examples
-    ---------
+    --------
     .. manim:: ExampleLine3D
         :save_last_frame:
 
@@ -725,18 +861,16 @@ class Line3D(Cylinder):
                 line = Line3D(start=np.array([0, 0, 0]), end=np.array([2, 2, 2]))
                 self.set_camera_orientation(phi=75 * DEGREES, theta=30 * DEGREES)
                 self.add(axes, line)
-
-    Parameters
-    ---------
-    start : :class:`numpy.array`
-        The start position of the line.
-    end : :class:`numpy.array`
-        The end position of the line.
-    thickness : :class:`float`
-        The thickness of the line.
     """
 
-    def __init__(self, start=LEFT, end=RIGHT, thickness=0.02, color=None, **kwargs):
+    def __init__(
+        self,
+        start: np.ndarray = LEFT,
+        end: np.ndarray = RIGHT,
+        thickness: float = 0.02,
+        color=None,
+        **kwargs,
+    ):
         self.thickness = thickness
         self.set_start_and_end_attrs(start, end, **kwargs)
         if color is not None:
@@ -745,7 +879,15 @@ class Line3D(Cylinder):
     def set_start_and_end_attrs(self, start, end, **kwargs):
         """Sets the start and end points of the line.
 
-        If either ``start`` or ``end`` are :class:`Mobjects <.Mobject>`, this gives their centers.
+        If either ``start`` or ``end`` are :class:`Mobjects <.Mobject>`,
+        this gives their centers.
+
+        Parameters
+        ----------
+        start
+            Starting point or :class:`Mobject`.
+        end
+            Ending point or :class:`Mobject`.
         """
         rough_start = self.pointify(start)
         rough_end = self.pointify(end)
@@ -775,9 +917,23 @@ class Line3D(Cylinder):
         return np.array(mob_or_point)
 
     def get_start(self):
+        """Returns the starting point of the :class:`Line3D`.
+
+        Returns
+        -------
+        start : :class:`numpy.array`
+            Starting point of the :class:`Line3D`.
+        """
         return self.start
 
     def get_end(self):
+        """Returns the ending point of the :class:`Line3D`.
+
+        Returns
+        -------
+        end : :class:`numpy.array`
+            Ending point of the :class:`Line3D`.
+        """
         return self.end
 
     @classmethod
@@ -864,8 +1020,23 @@ class Line3D(Cylinder):
 class Arrow3D(Line3D):
     """An arrow made out of a cylindrical line and a conical tip.
 
+    Parameters
+    ----------
+    start
+        The start position of the arrow.
+    end
+        The end position of the arrow.
+    thickness
+        The thickness of the arrow.
+    height
+        The height of the conical tip.
+    base_radius
+        The base radius of the conical tip.
+    color
+        The color of the arrow.
+
     Examples
-    ---------
+    --------
     .. manim:: ExampleArrow3D
         :save_last_frame:
 
@@ -879,28 +1050,15 @@ class Arrow3D(Line3D):
                 )
                 self.set_camera_orientation(phi=75 * DEGREES, theta=30 * DEGREES)
                 self.add(axes, arrow)
-
-    Parameters
-    ---------
-    start : :class:`numpy.array`
-        The start position of the arrow.
-    end : :class:`numpy.array`
-        The end position of the arrow.
-    thickness : :class:`float`
-        The thickness of the arrow.
-    height : :class:`float`
-        The height of the conical tip.
-    base_radius: :class:`float`
-        The base radius of the conical tip.
     """
 
     def __init__(
         self,
-        start=LEFT,
-        end=RIGHT,
-        thickness=0.02,
-        height=0.3,
-        base_radius=0.08,
+        start: np.ndarray = LEFT,
+        end: np.ndarray = RIGHT,
+        thickness: float = 0.02,
+        height: float = 0.3,
+        base_radius: float = 0.08,
         color=WHITE,
         **kwargs,
     ):
@@ -926,8 +1084,22 @@ class Arrow3D(Line3D):
 class Torus(Surface):
     """A torus.
 
+    Parameters
+    ----------
+    major_radius
+        Distance from the center of the tube to the center of the torus.
+    minor_radius
+        Radius of the tube.
+    u_range
+        The range of the ``u`` variable: ``(u_min, u_max)``.
+    v_range
+        The range of the ``v`` variable: ``(v_min, v_max)``.
+    resolution
+        The number of samples taken of the :class:`Torus`. A tuple can be
+        used to define different resolutions for ``u`` and ``v`` respectively.
+
     Examples
-    ---------
+    --------
     .. manim :: ExampleTorus
         :save_last_frame:
 
@@ -937,27 +1109,20 @@ class Torus(Surface):
                 torus = Torus()
                 self.set_camera_orientation(phi=75 * DEGREES, theta=30 * DEGREES)
                 self.add(axes, torus)
-
-    Parameters
-    ---------
-    major_radius : :class:`float`
-        Distance from the center of the tube to the center of the torus.
-    minor_radius : :class:`float`
-        Radius of the tube.
     """
 
     def __init__(
         self,
-        major_radius=3,
-        minor_radius=1,
+        major_radius: float = 3,
+        minor_radius: float = 1,
         u_range=(0, TAU),
         v_range=(0, TAU),
         resolution=None,
         **kwargs,
     ):
-        if config.renderer == "opengl":
+        if config.renderer == RendererType.OPENGL:
             res_value = (101, 101)
-        else:
+        elif config.renderer == RendererType.CAIRO:
             res_value = (24, 24)
 
         resolution = resolution if resolution is not None else res_value
