@@ -1,5 +1,6 @@
+from __future__ import annotations
+
 import types
-from importlib import import_module
 
 import pkg_resources
 
