@@ -8,9 +8,8 @@ import json
 import os
 import shutil
 import subprocess
-import sys
 from pathlib import Path
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
 import numpy as np
 import srt
@@ -21,7 +20,7 @@ from manim import __version__
 
 from .. import config, logger
 from .._config.logger_utils import set_file_logger
-from ..constants import GIF_FILE_EXTENSION
+from ..constants import RendererType
 from ..utils.file_ops import (
     add_extension_if_not_present,
     add_version_before_extension,
@@ -36,6 +35,9 @@ from ..utils.file_ops import (
 from ..utils.sounds import get_full_sound_file_path
 from .section import DefaultSectionType, Section
 
+if TYPE_CHECKING:
+    from manim.renderer.opengl_renderer import OpenGLRenderer
+
 
 class SceneFileWriter:
     """
@@ -50,7 +52,7 @@ class SceneFileWriter:
         sections : list of :class:`.Section`
             used to segment scene
 
-        sections_output_dir : str
+        sections_output_dir : :class:`pathlib.Path`
             where are section videos stored
 
         output_name : str
@@ -136,7 +138,7 @@ class SceneFileWriter:
             )
 
             # TODO: /dev/null would be good in case sections_output_dir is used without bein set (doesn't work on Windows), everyone likes defensive programming, right?
-            self.sections_output_dir = ""
+            self.sections_output_dir = Path("")
             if config.save_sections:
                 self.sections_output_dir = guarantee_existence(
                     config.get_dir(
@@ -146,7 +148,7 @@ class SceneFileWriter:
 
             if is_gif_format():
                 self.gif_file_path = add_extension_if_not_present(
-                    self.output_name, GIF_FILE_EXTENSION
+                    self.output_name, ".gif"
                 )
 
                 if not config["output_file"]:
@@ -200,13 +202,13 @@ class SceneFileWriter:
             ),
         )
 
-    def add_partial_movie_file(self, hash_animation):
+    def add_partial_movie_file(self, hash_animation: str):
         """Adds a new partial movie file path to `scene.partial_movie_files` and current section from a hash.
         This method will compute the path from the hash. In addition to that it adds the new animation to the current section.
 
         Parameters
         ----------
-        hash_animation : str
+        hash_animation
             Hash of the animation.
         """
         if not hasattr(self, "partial_movie_directory") or not write_to_movie():
@@ -267,21 +269,26 @@ class SceneFileWriter:
         """
         self.audio_segment = AudioSegment.silent()
 
-    def add_audio_segment(self, new_segment, time=None, gain_to_background=None):
+    def add_audio_segment(
+        self,
+        new_segment: AudioSegment,
+        time: float | None = None,
+        gain_to_background: float | None = None,
+    ):
         """
         This method adds an audio segment from an
         AudioSegment type object and suitable parameters.
 
         Parameters
         ----------
-        new_segment : AudioSegment
+        new_segment
             The audio segment to add
 
-        time : int, float, optional
+        time
             the timestamp at which the
             sound should be added.
 
-        gain_to_background : optional
+        gain_to_background
             The gain of the segment from the background.
         """
         if not self.includes_sound:
@@ -307,19 +314,25 @@ class SceneFileWriter:
             gain_during_overlay=gain_to_background,
         )
 
-    def add_sound(self, sound_file, time=None, gain=None, **kwargs):
+    def add_sound(
+        self,
+        sound_file: str,
+        time: float | None = None,
+        gain: float | None = None,
+        **kwargs,
+    ):
         """
         This method adds an audio segment from a sound file.
 
         Parameters
         ----------
-        sound_file : str
+        sound_file
             The path to the sound file.
 
-        time : float or int, optional
+        time
             The timestamp at which the audio should be added.
 
-        gain : optional
+        gain
             The gain of the given audio segment.
 
         **kwargs
@@ -334,52 +347,52 @@ class SceneFileWriter:
         self.add_audio_segment(new_segment, time, **kwargs)
 
     # Writers
-    def begin_animation(self, allow_write=False, file_path=None):
+    def begin_animation(self, allow_write: bool = False, file_path=None):
         """
         Used internally by manim to stream the animation to FFMPEG for
         displaying or writing to a file.
 
         Parameters
         ----------
-        allow_write : bool, optional
+        allow_write
             Whether or not to write to a video file.
         """
         if write_to_movie() and allow_write:
             self.open_movie_pipe(file_path=file_path)
 
-    def end_animation(self, allow_write=False):
+    def end_animation(self, allow_write: bool = False):
         """
         Internally used by Manim to stop streaming to
         FFMPEG gracefully.
 
         Parameters
         ----------
-        allow_write : bool, optional
+        allow_write
             Whether or not to write to a video file.
         """
         if write_to_movie() and allow_write:
             self.close_movie_pipe()
 
-    def write_frame(self, frame_or_renderer):
+    def write_frame(self, frame_or_renderer: np.ndarray | OpenGLRenderer):
         """
         Used internally by Manim to write a frame to
         the FFMPEG input buffer.
 
         Parameters
         ----------
-        frame : np.array
+        frame_or_renderer
             Pixel array of the frame.
         """
-        if config.renderer == "opengl":
+        if config.renderer == RendererType.OPENGL:
             self.write_opengl_frame(frame_or_renderer)
-        else:
+        elif config.renderer == RendererType.CAIRO:
             frame = frame_or_renderer
             if write_to_movie():
                 self.writing_process.stdin.write(frame.tobytes())
             if is_png_format() and not config["dry_run"]:
                 self.output_image_from_array(frame)
 
-    def write_opengl_frame(self, renderer):
+    def write_opengl_frame(self, renderer: OpenGLRenderer):
         if write_to_movie():
             self.writing_process.stdin.write(
                 renderer.get_raw_frame_buffer_object_data(),
@@ -411,14 +424,14 @@ class SceneFileWriter:
             image.save(f"{target_dir}{self.frame_count}{ext}")
         self.frame_count += 1
 
-    def save_final_image(self, image):
+    def save_final_image(self, image: np.ndarray):
         """
         The name is a misnomer. This method saves the image
         passed to it as an in the default image directory.
 
         Parameters
         ----------
-        image : np.array
+        image
             The pixel array of the image to save.
         """
         if config["dry_run"]:
@@ -467,7 +480,7 @@ class SceneFileWriter:
         fps = config["frame_rate"]
         if fps == int(fps):  # fps is integer
             fps = int(fps)
-        if config.renderer == "opengl":
+        if config.renderer == RendererType.OPENGL:
             width, height = self.renderer.get_pixel_shape()
         else:
             height = config["pixel_height"]
@@ -492,7 +505,7 @@ class SceneFileWriter:
             "-metadata",
             f"comment=Rendered with Manim Community v{__version__}",
         ]
-        if config.renderer == "opengl":
+        if config.renderer == RendererType.OPENGL:
             command += ["-vf", "vflip"]
         if is_webm_format():
             command += ["-vcodec", "libvpx-vp9", "-auto-alt-ref", "0"]
@@ -516,12 +529,12 @@ class SceneFileWriter:
             {"path": f"'{self.partial_movie_file_path}'"},
         )
 
-    def is_already_cached(self, hash_invocation):
+    def is_already_cached(self, hash_invocation: str):
         """Will check if a file named with `hash_invocation` exists.
 
         Parameters
         ----------
-        hash_invocation : :class:`str`
+        hash_invocation
             The hash corresponding to an invocation to either `scene.play` or `scene.wait`.
 
         Returns
@@ -540,21 +553,19 @@ class SceneFileWriter:
     def combine_files(
         self,
         input_files: list[str],
-        output_file: Path | str,
+        output_file: Path,
         create_gif=False,
         includes_sound=False,
     ):
-        file_list = str(self.partial_movie_directory / "partial_movie_file_list.txt")
+        file_list = self.partial_movie_directory / "partial_movie_file_list.txt"
         logger.debug(
             f"Partial movie files to combine ({len(input_files)} files): %(p)s",
             {"p": input_files[:5]},
         )
-        with open(file_list, "w", encoding="utf-8") as fp:
+        with file_list.open("w", encoding="utf-8") as fp:
             fp.write("# This file is used internally by FFMPEG.\n")
             for pf_path in input_files:
-                pf_path = str(pf_path)
-                if os.name == "nt":
-                    pf_path = pf_path.replace("\\", "/")
+                pf_path = Path(pf_path).as_posix()
                 fp.write(f"file 'file:{pf_path}'\n")
         commands = [
             config.ffmpeg_executable,
@@ -564,7 +575,7 @@ class SceneFileWriter:
             "-safe",
             "0",
             "-i",
-            file_list,
+            str(file_list),
             "-loglevel",
             config.ffmpeg_loglevel.lower(),
             "-metadata",
@@ -603,7 +614,6 @@ class SceneFileWriter:
         movie_file_path = self.movie_file_path
         if is_gif_format():
             movie_file_path = self.gif_file_path
-        movie_file_path = str(movie_file_path)
         logger.info("Combining to Movie file.")
         self.combine_files(
             partial_movie_files,
@@ -614,21 +624,22 @@ class SceneFileWriter:
 
         # handle sound
         if self.includes_sound:
-            extension = config["movie_file_extension"]
-            sound_file_path = movie_file_path.replace(extension, ".wav")
+            sound_file_path = movie_file_path.with_suffix(".wav")
             # Makes sure sound file length will match video file
             self.add_audio_segment(AudioSegment.silent(0))
             self.audio_segment.export(
                 sound_file_path,
                 bitrate="312k",
             )
-            temp_file_path = movie_file_path.replace(extension, f"_temp{extension}")
+            temp_file_path = movie_file_path.with_name(
+                f"{movie_file_path.stem}_temp{movie_file_path.suffix}"
+            )
             commands = [
                 config.ffmpeg_executable,
                 "-i",
-                movie_file_path,
+                str(movie_file_path),
                 "-i",
-                sound_file_path,
+                str(sound_file_path),
                 "-y",  # overwrite output file if it exists
                 "-c:v",
                 "copy",
@@ -647,13 +658,13 @@ class SceneFileWriter:
                 "-metadata",
                 f"comment=Rendered with Manim Community v{__version__}",
                 # "-shortest",
-                temp_file_path,
+                str(temp_file_path),
             ]
             subprocess.call(commands)
-            shutil.move(temp_file_path, movie_file_path)
-            os.remove(sound_file_path)
+            shutil.move(str(temp_file_path), str(movie_file_path))
+            sound_file_path.unlink()
 
-        self.print_file_ready_message(movie_file_path)
+        self.print_file_ready_message(str(movie_file_path))
         if write_to_movie():
             for file_path in partial_movie_files:
                 # We have to modify the accessed time so if we have to clean the cache we remove the one used the longest.
@@ -670,12 +681,10 @@ class SceneFileWriter:
                 logger.info(f"Combining partial files for section '{section.name}'")
                 self.combine_files(
                     section.get_clean_partial_movie_files(),
-                    os.path.join(self.sections_output_dir, section.video),
+                    self.sections_output_dir / section.video,
                 )
                 sections_index.append(section.get_dict(self.sections_output_dir))
-        with open(
-            os.path.join(self.sections_output_dir, f"{self.output_name}.json"), "w"
-        ) as file:
+        with (self.sections_output_dir / f"{self.output_name}.json").open("w") as file:
             json.dump(sections_index, file, indent=4)
 
     def clean_cache(self):
@@ -718,8 +727,7 @@ class SceneFileWriter:
     def write_subcaption_file(self):
         """Writes the subcaption file."""
         subcaption_file = Path(config.output_file).with_suffix(".srt")
-        with open(subcaption_file, "w") as f:
-            f.write(srt.compose(self.subcaptions))
+        subcaption_file.write_text(srt.compose(self.subcaptions))
         logger.info(f"Subcaption file has been written as {subcaption_file}")
 
     def print_file_ready_message(self, file_path):
