@@ -14,8 +14,15 @@ from typing import Any
 
 import numpy as np
 
+from manim.animation.animation import Animation
+from manim.camera.camera import Camera
+from manim.mobject.mobject import Mobject
+
 from .. import config, logger
 
+if typing.TYPE_CHECKING:
+    from manim.scene.scene import Scene
+
 # Sometimes there are elements that are not suitable for hashing (too long or
 # run-dependent).  This is used to filter them out.
 KEYS_TO_FILTER_OUT = {
@@ -50,14 +57,14 @@ class _Memoizer:
         cls._already_processed.clear()
 
     @classmethod
-    def check_already_processed_decorator(cls: _Memoizer, is_method=False):
+    def check_already_processed_decorator(cls: _Memoizer, is_method: bool = False):
         """Decorator to handle the arguments that goes through the decorated function.
         Returns _ALREADY_PROCESSED_PLACEHOLDER if the obj has been processed, or lets
         the decorated function call go ahead.
 
         Parameters
         ----------
-        is_method : bool, optional
+        is_method
             Whether the function passed is a method, by default False.
         """
 
@@ -81,7 +88,7 @@ class _Memoizer:
 
         Parameters
         ----------
-        obj : Any
+        obj
             The object to check.
 
         Returns
@@ -98,7 +105,7 @@ class _Memoizer:
 
         Parameters
         ----------
-        obj : Any
+        obj
             The object to mark as processed.
         """
         cls._handle_already_processed(obj, lambda x: x)
@@ -164,7 +171,7 @@ class _Memoizer:
 
 
 class _CustomEncoder(json.JSONEncoder):
-    def default(self, obj):
+    def default(self, obj: Any):
         """
         This method is used to serialize objects to JSON format.
 
@@ -178,7 +185,7 @@ class _CustomEncoder(json.JSONEncoder):
 
         Parameters
         ----------
-        obj : Any
+        obj
             Arbitrary object to convert
 
         Returns
@@ -225,7 +232,7 @@ class _CustomEncoder(json.JSONEncoder):
         # Serialize it with only the type of the object. You can change this to whatever string when debugging the serialization process.
         return str(type(obj))
 
-    def _cleaned_iterable(self, iterable):
+    def _cleaned_iterable(self, iterable: typing.Iterable[Any]):
         """Check for circular reference at each iterable that will go through the JSONEncoder, as well as key of the wrong format.
 
         If a key with a bad format is found (i.e not a int, string, or float), it gets replaced byt its hash using the same process implemented here.
@@ -233,7 +240,7 @@ class _CustomEncoder(json.JSONEncoder):
 
         Parameters
         ----------
-        iterable : Iterable[Any]
+        iterable
             The iterable to check.
         """
 
@@ -278,12 +285,12 @@ class _CustomEncoder(json.JSONEncoder):
         elif isinstance(iterable, dict):
             return _iter_check_dict(iterable)
 
-    def encode(self, obj):
+    def encode(self, obj: Any):
         """Overriding of :meth:`JSONEncoder.encode`, to make our own process.
 
         Parameters
         ----------
-        obj: Any
+        obj
             The object to encode in JSON.
 
         Returns
@@ -297,12 +304,12 @@ class _CustomEncoder(json.JSONEncoder):
         return super().encode(obj)
 
 
-def get_json(obj):
+def get_json(obj: dict):
     """Recursively serialize `object` to JSON using the :class:`CustomEncoder` class.
 
     Parameters
     ----------
-    dict_config : :class:`dict`
+    obj
         The dict to flatten
 
     Returns
@@ -314,25 +321,25 @@ def get_json(obj):
 
 
 def get_hash_from_play_call(
-    scene_object,
-    camera_object,
-    animations_list,
-    current_mobjects_list,
+    scene_object: Scene,
+    camera_object: Camera,
+    animations_list: typing.Iterable[Animation],
+    current_mobjects_list: typing.Iterable[Mobject],
 ) -> str:
     """Take the list of animations and a list of mobjects and output their hashes. This is meant to be used for `scene.play` function.
 
     Parameters
     -----------
-    scene_object : :class:`~.Scene`
+    scene_object
         The scene object.
 
-    camera_object : :class:`~.Camera`
+    camera_object
         The camera object used in the scene.
 
-    animations_list : Iterable[:class:`~.Animation`]
+    animations_list
         The list of animations.
 
-    current_mobjects_list : Iterable[:class:`~.Mobject`]
+    current_mobjects_list
         The list of mobjects.
 
     Returns
