@@ -14,6 +14,8 @@ import re
 import unicodedata
 from pathlib import Path
 
+from manim.utils.tex import TexTemplate
+
 from .. import config, logger
 
 
@@ -25,21 +27,25 @@ def tex_hash(expression):
     return hasher.hexdigest()[:16]
 
 
-def tex_to_svg_file(expression, environment=None, tex_template=None):
+def tex_to_svg_file(
+    expression: str,
+    environment: str | None = None,
+    tex_template: TexTemplate | None = None,
+):
     """Takes a tex expression and returns the svg version of the compiled tex
 
     Parameters
     ----------
-    expression : :class:`str`
+    expression
         String containing the TeX expression to be rendered, e.g. ``\\sqrt{2}`` or ``foo``
-    environment : Optional[:class:`str`], optional
+    environment
         The string containing the environment in which the expression should be typeset, e.g. ``align*``
-    tex_template : Optional[:class:`~.TexTemplate`], optional
+    tex_template
         Template class used to typesetting. If not set, use default template set via `config["tex_template"]`
 
     Returns
     -------
-    :class:`str`
+    :class:`Path`
         Path to generated SVG file.
     """
     if tex_template is None:
@@ -53,22 +59,26 @@ def tex_to_svg_file(expression, environment=None, tex_template=None):
     return convert_to_svg(dvi_file, tex_template.output_format)
 
 
-def generate_tex_file(expression, environment=None, tex_template=None):
+def generate_tex_file(
+    expression: str,
+    environment: str | None = None,
+    tex_template: TexTemplate | None = None,
+):
     """Takes a tex expression (and an optional tex environment),
     and returns a fully formed tex file ready for compilation.
 
     Parameters
     ----------
-    expression : :class:`str`
+    expression
         String containing the TeX expression to be rendered, e.g. ``\\sqrt{2}`` or ``foo``
-    environment : Optional[:class:`str`], optional
+    environment
         The string containing the environment in which the expression should be typeset, e.g. ``align*``
-    tex_template : Optional[:class:`~.TexTemplate`], optional
+    tex_template
         Template class used to typesetting. If not set, use default template set via `config["tex_template"]`
 
     Returns
     -------
-    :class:`str`
+    :class:`Path`
         Path to generated TeX file
     """
     if tex_template is None:
@@ -82,29 +92,30 @@ def generate_tex_file(expression, environment=None, tex_template=None):
     if not tex_dir.exists():
         tex_dir.mkdir()
 
-    result = Path(tex_dir) / (tex_hash(output) + ".tex")
+    result = tex_dir / (tex_hash(output) + ".tex")
     if not result.exists():
         logger.info(
             "Writing %(expression)s to %(path)s",
             {"expression": expression, "path": f"{result}"},
         )
-        with open(result, "w", encoding="utf-8") as outfile:
-            outfile.write(output)
-    return result.as_posix()
+        result.write_text(output, encoding="utf-8")
+    return result
 
 
-def tex_compilation_command(tex_compiler, output_format, tex_file, tex_dir):
+def tex_compilation_command(
+    tex_compiler: str, output_format: str, tex_file: Path, tex_dir: Path
+) -> str:
     """Prepares the tex compilation command with all necessary cli flags
 
     Parameters
     ----------
-    tex_compiler : :class:`str`
+    tex_compiler
         String containing the compiler to be used, e.g. ``pdflatex`` or ``lualatex``
-    output_format : :class:`str`
+    output_format
         String containing the output format generated by the compiler, e.g. ``.dvi`` or ``.pdf``
-    tex_file : :class:`str`
+    tex_file
         File name of TeX file to be typeset.
-    tex_dir : :class:`str`
+    tex_dir
         Path to the directory where compiler output will be stored.
 
     Returns
@@ -157,28 +168,26 @@ def insight_package_not_found_error(matching):
     yield f"Install {matching[1]} it using your LaTeX package manager, or check for typos."
 
 
-def compile_tex(tex_file, tex_compiler, output_format):
+def compile_tex(tex_file: Path, tex_compiler: str, output_format: str) -> Path:
     """Compiles a tex_file into a .dvi or a .xdv or a .pdf
 
     Parameters
     ----------
-    tex_file : :class:`str`
+    tex_file
         File name of TeX file to be typeset.
-    tex_compiler : :class:`str`
+    tex_compiler
         String containing the compiler to be used, e.g. ``pdflatex`` or ``lualatex``
-    output_format : :class:`str`
+    output_format
         String containing the output format generated by the compiler, e.g. ``.dvi`` or ``.pdf``
 
     Returns
     -------
-    :class:`str`
+    :class:`Path`
         Path to generated output file in desired format (DVI, XDV or PDF).
     """
-    result = tex_file.replace(".tex", output_format)
-    result = Path(result).as_posix()
-    tex_file = Path(tex_file).as_posix()
-    tex_dir = Path(config.get_dir("tex_dir")).as_posix()
-    if not Path(result).exists():
+    result = tex_file.with_suffix(output_format)
+    tex_dir = config.get_dir("tex_dir")
+    if not result.exists():
         command = tex_compilation_command(
             tex_compiler,
             output_format,
@@ -187,7 +196,7 @@ def compile_tex(tex_file, tex_compiler, output_format):
         )
         exit_code = os.system(command)
         if exit_code != 0:
-            log_file = tex_file.replace(".tex", ".log")
+            log_file = tex_file.with_suffix(".log")
             print_all_tex_errors(log_file, tex_compiler, tex_file)
             raise ValueError(
                 f"{tex_compiler} error converting to"
@@ -197,27 +206,24 @@ def compile_tex(tex_file, tex_compiler, output_format):
     return result
 
 
-def convert_to_svg(dvi_file, extension, page=1):
+def convert_to_svg(dvi_file: Path, extension: str, page: int = 1):
     """Converts a .dvi, .xdv, or .pdf file into an svg using dvisvgm.
 
     Parameters
     ----------
-    dvi_file : :class:`str`
+    dvi_file
         File name of the input file to be converted.
-    extension : :class:`str`
+    extension
         String containing the file extension and thus indicating the file type, e.g. ``.dvi`` or ``.pdf``
-    page : Optional[:class:`int`], optional
+    page
         Page to be converted if input file is multi-page.
 
     Returns
     -------
-    :class:`str`
+    :class:`Path`
         Path to generated SVG file.
     """
-    result = dvi_file.replace(extension, ".svg")
-    result = Path(result)
-    result_str = result.as_posix()
-    dvi_file = Path(dvi_file).as_posix()
+    result = dvi_file.with_suffix(".svg")
     if not result.exists():
         commands = [
             "dvisvgm",
@@ -226,7 +232,7 @@ def convert_to_svg(dvi_file, extension, page=1):
             f'"{dvi_file}"',
             "-n",
             "-v 0",
-            "-o " + f'"{result_str}"',
+            "-o " + f'"{result}"',
             ">",
             os.devnull,
         ]
@@ -235,33 +241,31 @@ def convert_to_svg(dvi_file, extension, page=1):
     # if the file does not exist now, this means conversion failed
     if not result.exists():
         raise ValueError(
-            f"Your installation does not support converting {extension} files to SVG."
+            f"Your installation does not support converting {dvi_file.suffix} files to SVG."
             f" Consider updating dvisvgm to at least version 2.4."
             f" If this does not solve the problem, please refer to our troubleshooting guide at:"
             f" https://docs.manim.community/en/stable/installation/troubleshooting.html",
         )
 
-    return result_str
+    return result
 
 
-def print_all_tex_errors(log_file, tex_compiler, tex_file):
-    if not Path(log_file).exists():
+def print_all_tex_errors(log_file: Path, tex_compiler: str, tex_file: Path) -> None:
+    if not log_file.exists():
         raise RuntimeError(
             f"{tex_compiler} failed but did not produce a log file. "
             "Check your LaTeX installation.",
         )
-    with open(log_file) as f:
+    with log_file.open(encoding="utf-8") as f:
         tex_compilation_log = f.readlines()
-        error_indices = [
-            index
-            for index, line in enumerate(tex_compilation_log)
-            if line.startswith("!")
-        ]
-        if error_indices:
-            with open(tex_file) as g:
-                tex = g.readlines()
-                for error_index in error_indices:
-                    print_tex_error(tex_compilation_log, error_index, tex)
+    error_indices = [
+        index for index, line in enumerate(tex_compilation_log) if line.startswith("!")
+    ]
+    if error_indices:
+        with tex_file.open() as f:
+            tex = f.readlines()
+        for error_index in error_indices:
+            print_tex_error(tex_compilation_log, error_index, tex)
 
 
 LATEX_ERROR_INSIGHTS = [
